# WARNING: This package is synchronized with Fedora!

%bcond_with bootstrap

%bcond_with lint
%bcond_without tests

# Modern distributions (using RPM v4.19+; for example, Fedora 39+) do not
# require the %%pre scriptlet for creating users/groups because the sysusers
# feature is now built directly into RPM.  Simply including the sysusers
# `mock.conf` file in a package payload is sufficient to leverage this feature.
# However, for older distributions that lack this capability, we still define
# the %%pre scriptlet.
%if (0%{?rhel} && 0%{?rhel} < 10) || (0%{?mageia} && 0%{?mageia} < 10) || (0%{?suse_version} && 0%{?suse_version} < 1660)
%bcond_without sysusers_compat
%else
%bcond_with sysusers_compat
%endif

%global __python %{__python3}
%global python_sitelib %{python3_sitelib}

Summary: Builds packages inside chroots
Name: mock
Version: 6.0
Release: %mkrel 5
License: GPL-2.0-or-later

Group: Development/Other

# Source is created by
# git clone https://github.com/rpm-software-management/mock.git
# cd mock
# git reset --hard %%{name}-%%{version}
# tito build --tgz
Source: https://github.com/rpm-software-management/%{name}/releases/download/%{name}-%{version}-1/%{name}-%{version}.tar.gz
#
# Mageia patches
Patch: 0001-Pull-rpm-with-dnf5.patch
# End of Mageia patches
#
URL: https://github.com/rpm-software-management/mock/
BuildArch: noarch
Requires: tar
Requires: pigz
%if 0%{?mageia}
Requires: usermode-consoleonly
%else
Requires: usermode
%endif
Requires: createrepo_c

# We know that the current version of mock isn't compatible with older variants,
# and we want to enforce automatic upgrades.
Conflicts: mock-core-configs < 33

# Requires 'mock-core-configs', or replacement (GitHub PR#544).
Requires: mock-configs
Requires: %{name}-filesystem = %{version}-%{release}
%if ! 0%{?mageia}
# This is still preferred package providing 'mock-configs'
Suggests: mock-core-configs
%else
# Install extra configs by default
Recommends: mock-mageia-configs
%endif

Requires: systemd
%if 0%{?fedora} || 0%{?rhel}
Requires: systemd-container
%endif
Requires: coreutils
%if 0%{?fedora}
Suggests: iproute
%endif
%if 0%{?mageia}
Suggests: iproute2
%endif
BuildRequires: bash-completion
Requires: python%{python3_pkgversion}-distro
Requires: python%{python3_pkgversion}-jinja2
Requires: python%{python3_pkgversion}-requests
Requires: python%{python3_pkgversion}-rpm
Requires: python%{python3_pkgversion}-pyroute2
Requires: python%{python3_pkgversion}-templated-dictionary >= 1.5
Requires: python%{python3_pkgversion}-backoff
BuildRequires: python%{python3_pkgversion}-backoff
BuildRequires: python%{python3_pkgversion}-devel
%if %{with lint}
BuildRequires: python%{python3_pkgversion}-pylint
%endif
BuildRequires: python%{python3_pkgversion}-rpm
BuildRequires: python%{python3_pkgversion}-rpmautospec-core

BuildRequires: argparse-manpage

%if 0%{?fedora} >= 38
# DNF5 stack
Recommends: dnf5
Recommends: dnf5-plugins
%endif

# We need these for the Mageia targets
Requires: dnf
Requires: dnf-plugins-core
Recommends: dnf-utils

# DNF4 stack
Recommends: python3-dnf
Recommends: python3-dnf-plugins-core

# YUM stack, dnf-utils replace yum-utils
Recommends: yum
Recommends: dnf-utils

Recommends: btrfs-progs
%if ! 0%{?mageia}
Suggests: qemu-user-static
Suggests: procenv
%else
Recommends: qemu-user-static
Recommends: procenv
%endif
Recommends: buildah
Recommends: podman
Recommends: fuse-overlayfs

%if %{with tests}
BuildRequires: locales
BuildRequires: python%{python3_pkgversion}-distro
BuildRequires: python%{python3_pkgversion}-jinja2
BuildRequires: python%{python3_pkgversion}-jsonschema
BuildRequires: python%{python3_pkgversion}-pyroute2
BuildRequires: python%{python3_pkgversion}-pytest
BuildRequires: python%{python3_pkgversion}-requests
BuildRequires: python%{python3_pkgversion}-templated-dictionary
%endif

%if 0%{?mageia} && 0%{!?with_bootstrap:1}
BuildRequires: mock
%endif
%if 0%{?fedora} || 0%{?rhel}
BuildRequires: perl-interpreter
%else
BuildRequires: perl
%endif
# hwinfo plugin
Requires: util-linux
Requires: coreutils
Requires: procps-ng
Requires: shadow-utils


%description
Mock takes an SRPM and builds it in a chroot.

%package scm
Summary: Mock SCM integration module
Requires: %{name} = %{version}-%{release}
Recommends: cvs
Recommends: git
Recommends: subversion
Recommends: tar

# We could migrate to 'copr-distgit-client'
Recommends: rpkg

%description scm
Mock SCM integration module.

%package lvm
Summary: LVM plugin for mock
Requires: %{name} = %{version}-%{release}
Requires: lvm2

%description lvm
Mock plugin that enables using LVM as a backend and support creating snapshots
of the buildroot.

%package rpmautospec
Summary: Rpmautospec plugin for mock
Requires: %{name} = %{version}-%{release}
# This lets mock determine if a spec file needs to be processed with rpmautospec.
Requires: python%{python3_pkgversion}-rpmautospec-core

%description rpmautospec
Mock plugin that preprocesses spec files using rpmautospec.

%package filesystem
Summary:  Mock filesystem layout
Requires(pre):  shadow-utils
BuildRequires:  systemd-rpm-macros

%if %{with sysusers_compat}
Requires(pre): shadow-utils
%endif

%description filesystem
Filesystem layout and group for Mock.

%prep
%autosetup -p1
for file in py/mock.py py/mock-parse-buildlog.py; do
  sed -i 1"s|#!/usr/bin/python3 |#!%{__python} |" $file
done

%build
for i in py/mockbuild/constants.py py/mock-parse-buildlog.py; do
    perl -p -i -e 's|^VERSION\s*=.*|VERSION="%{version}"|' $i
    perl -p -i -e 's|^SYSCONFDIR\s*=.*|SYSCONFDIR="%{_sysconfdir}"|' $i
    perl -p -i -e 's|^PYTHONDIR\s*=.*|PYTHONDIR="%{python_sitelib}"|' $i
    perl -p -i -e 's|^PKGPYTHONDIR\s*=.*|PKGPYTHONDIR="%{python_sitelib}/mockbuild"|' $i
done
for i in docs/mock.1 docs/mock-parse-buildlog.1; do
    perl -p -i -e 's|\@VERSION\@|%{version}"|' $i
done

%if ! %{with bootstrap}
./precompile-bash-completion "mock.complete"
%endif

%if ! 0%{?mageia}
# this is what %%sysusers_create_compat will expand to
%{_rpmconfigdir}/sysusers.generate-pre.sh mock.conf > sysusers_script
%endif

argparse-manpage --pyfile ./py/mock-hermetic-repo.py --function _argparser > mock-hermetic-repo.1


%install
#base filesystem
mkdir -p %{buildroot}%{_sysconfdir}/mock/eol/templates
mkdir -p %{buildroot}%{_sysconfdir}/mock/templates

install -d %{buildroot}%{_bindir}
install -d %{buildroot}%{_libexecdir}/mock
install mockchain %{buildroot}%{_bindir}/mockchain
install py/mock-hermetic-repo.py %{buildroot}%{_bindir}/mock-hermetic-repo
install py/mock-parse-buildlog.py %{buildroot}%{_bindir}/mock-parse-buildlog
install py/mock.py %{buildroot}%{_libexecdir}/mock/mock
ln -s consolehelper %{buildroot}%{_bindir}/mock
 
install -d %{buildroot}%{_sysconfdir}/pam.d
cp -a etc/pam/* %{buildroot}%{_sysconfdir}/pam.d/

install -d %{buildroot}%{_sysconfdir}/mock
cp -a etc/mock/* %{buildroot}%{_sysconfdir}/mock/

install -d %{buildroot}%{_sysconfdir}/security/console.apps/
cp -a etc/consolehelper/mock %{buildroot}%{_sysconfdir}/security/console.apps/%{name}

install -d %{buildroot}%{_datadir}/bash-completion/completions/
cp -a etc/bash_completion.d/* %{buildroot}%{_datadir}/bash-completion/completions/
%if ! %{with bootstrap}
cp -a mock.complete %{buildroot}%{_datadir}/bash-completion/completions/mock
%endif
ln -s mock %{buildroot}%{_datadir}/bash-completion/completions/mock-parse-buildlog

install -d %{buildroot}%{_sysconfdir}/pki/mock
cp -a etc/pki/* %{buildroot}%{_sysconfdir}/pki/mock/

install -d %{buildroot}%{python_sitelib}/
cp -a py/mockbuild %{buildroot}%{python_sitelib}/

install -d %{buildroot}%{_mandir}/man1
cp -a docs/mock.1 docs/mock-parse-buildlog.1 mock-hermetic-repo.1 %{buildroot}%{_mandir}/man1/
install -d %{buildroot}%{_datadir}/cheat
cp -a docs/mock.cheat %{buildroot}%{_datadir}/cheat/mock

install -d %{buildroot}/var/lib/mock
install -d %{buildroot}/var/cache/mock

mkdir -p %{buildroot}%{_pkgdocdir}
install -p -m 0644 docs/buildroot-lock-schema-*.json %{buildroot}%{_pkgdocdir}
install -p -m 0644 docs/site-defaults.cfg %{buildroot}%{_pkgdocdir}

mkdir -p %{buildroot}%{_sysusersdir}
install -p -D -m 0644 %{name}.conf %{buildroot}%{_sysusersdir}

sed -i 's/^_MOCK_NVR = None$/_MOCK_NVR = "%name-%version-%release"/' \
    %{buildroot}%{_libexecdir}/mock/mock


%if %{with sysusers_compat}
%pre filesystem
# Some of these older distributions do not ship with the %%sysusers_*_compat.
# Instead of another ifdef/else here, we prefer to hardcode the scriptlet
# content here.
getent group 'mock' >/dev/null || groupadd -f -g '135' -r 'mock' || :
%endif


%check
%if %{with lint}
# ignore the errors for now, just print them and hopefully somebody will fix it one day
pylint-3 py/mockbuild/ py/*.py py/mockbuild/plugins/* || :
%endif

%if %{with tests}
./run-tests.sh --no-cov
%endif


%files
%defattr(0644, root, mock)
%dir %{_pkgdocdir}/
%doc %{_pkgdocdir}/site-defaults.cfg
%doc %{_pkgdocdir}/buildroot-lock-schema-*.json
%{_datadir}/bash-completion/completions/mock
%{_datadir}/bash-completion/completions/mock-parse-buildlog

%defattr(-, root, root)

# executables
%{_bindir}/mock
%{_bindir}/mockchain
%{_bindir}/mock-hermetic-repo
%{_bindir}/mock-parse-buildlog
%{_libexecdir}/mock

# python stuff
%{python_sitelib}/*
%exclude %{python_sitelib}/mockbuild/scm.*
%exclude %{python_sitelib}/mockbuild/__pycache__/scm.*
%exclude %{python_sitelib}/mockbuild/plugins/lvm_root.*
%exclude %{python_sitelib}/mockbuild/plugins/__pycache__/lvm_root.*
%exclude %{python_sitelib}/mockbuild/plugins/rpmautospec.*
%exclude %{python3_sitelib}/mockbuild/plugins/__pycache__/rpmautospec.*.py*

# config files
%dir  %{_sysconfdir}/%{name}
%config(noreplace) %{_sysconfdir}/%{name}/*.ini
%config(noreplace) %{_sysconfdir}/%{name}/hermetic-build.cfg
%config(noreplace) %{_sysconfdir}/pam.d/%{name}
%config(noreplace) %{_sysconfdir}/security/console.apps/%{name}

# directory for personal gpg keys
%dir %{_sysconfdir}/pki/mock
%config(noreplace) %{_sysconfdir}/pki/mock/*

# docs
%{_mandir}/man1/mock.1*
%{_mandir}/man1/mock-parse-buildlog.1*
%{_mandir}/man1/mock-hermetic-repo.1*
%{_datadir}/cheat/mock

# cache & build dirs
%defattr(0775, root, mock, 0775)
%dir %{_localstatedir}/cache/mock
%dir %{_localstatedir}/lib/mock

%files scm
%{python_sitelib}/mockbuild/scm.py*
%{python3_sitelib}/mockbuild/__pycache__/scm.*.py*

%files lvm
%{python_sitelib}/mockbuild/plugins/lvm_root.*
%{python3_sitelib}/mockbuild/plugins/__pycache__/lvm_root.*.py*

%files rpmautospec
%{python_sitelib}/mockbuild/plugins/rpmautospec.*
%{python3_sitelib}/mockbuild/plugins/__pycache__/rpmautospec.*.py*

%files filesystem
%license COPYING
%dir  %{_sysconfdir}/mock
%dir  %{_sysconfdir}/mock/eol
%dir  %{_sysconfdir}/mock/eol/templates
%dir  %{_sysconfdir}/mock/templates
%dir  %{_datadir}/cheat
%config(noreplace) %{_sysusersdir}/mock.conf



%changelog
* Wed Jul 02 2025 umeabot <umeabot> 6.0-5.mga10
+ Revision: 2237683
- Mageia 10 Mass Rebuild

* Fri Feb 28 2025 wally <wally> 6.0-4.mga10
+ Revision: 2153868
- pull rpm with dnf5 as otherwise rpm doesn't get pulled in Mageia and mock doesn't work

* Wed Feb 26 2025 wally <wally> 6.0-3.mga10
+ Revision: 2153005
- non-bootstrap build for python3.13

* Wed Feb 26 2025 wally <wally> 6.0-2.mga10
+ Revision: 2152996
- bootstrap build
- rebuild for python3.13

* Sun Jan 05 2025 wally <wally> 6.0-1.mga10
+ Revision: 2135507
- new version 6.0

* Sun Oct 13 2024 wally <wally> 5.9-1.mga10
+ Revision: 2106115
- new version 5.9

* Mon Sep 09 2024 wally <wally> 5.6-2.mga10
+ Revision: 2094757
- change suggests into recommends (mga#33478)

* Mon Jul 08 2024 wally <wally> 5.6-1.mga10
+ Revision: 2080296
- new version 5.6

* Thu Feb 15 2024 wally <wally> 5.5-1.mga10
+ Revision: 2041692
- new version 5.5

* Fri Feb 09 2024 wally <wally> 5.4-2.mga10
+ Revision: 2039991
- add patch from upstream pull request to fix bootstrap build for cross-arch

* Sat Feb 03 2024 wally <wally> 5.4-1.mga10
+ Revision: 2037001
- new version 5.4

* Sat Dec 09 2023 wally <wally> 5.1.1-2.mga10
+ Revision: 2016170
- rebuild for py3.12

* Thu Sep 21 2023 daviddavid <daviddavid> 5.1.1-1.mga10
+ Revision: 1989195
- new version: 5.1.1

* Thu Sep 21 2023 daviddavid <daviddavid> 5.1-1.mga10
+ Revision: 1989134
- new version: 5.1

* Mon Dec 05 2022 wally <wally> 3.5-1.mga9
+ Revision: 1918034
- new version 3.5

* Tue Nov 22 2022 luigiwalser <luigiwalser> 3.4-1.mga9
+ Revision: 1910032
- 3.4

* Thu Oct 27 2022 luigiwalser <luigiwalser> 3.3-1.mga9
+ Revision: 1899822
- 3.3

* Wed Jul 27 2022 luigiwalser <luigiwalser> 3.1-1.mga9
+ Revision: 1872494
- 3.1

* Fri Apr 15 2022 luigiwalser <luigiwalser> 3.0-1.mga9
+ Revision: 1850432
- 3.0

* Tue Mar 29 2022 umeabot <umeabot> 2.16-2.mga9
+ Revision: 1832163
- Mageia 9 Mass Rebuild

* Sun Feb 13 2022 luigiwalser <luigiwalser> 2.16-1.mga9
+ Revision: 1774103
- 2.16

* Sun Feb 06 2022 wally <wally> 2.15-2.mga9
+ Revision: 1772303
- rebuild for python3.10

* Thu Nov 25 2021 luigiwalser <luigiwalser> 2.15-1.mga9
+ Revision: 1759138
- 2.15

* Tue Nov 09 2021 luigiwalser <luigiwalser> 2.14-1.mga9
+ Revision: 1755341
- 2.14

* Sun Aug 08 2021 luigiwalser <luigiwalser> 2.12-1.mga9
+ Revision: 1740733
- 2.12

* Mon Mar 15 2021 wally <wally> 2.9-2.mga9
+ Revision: 1703554
- rebuild for python 3.9

* Tue Feb 02 2021 ngompa <ngompa> 2.9-1.mga8
+ Revision: 1674525
- Update to 2.9

* Wed Dec 30 2020 luigiwalser <luigiwalser> 2.8-1.mga8
+ Revision: 1665462
- 2.8

* Sun Dec 06 2020 ngompa <ngompa> 2.7-1.mga8
+ Revision: 1653936
- Rebase to version 2.7

* Sun Feb 16 2020 umeabot <umeabot> 1.4.15-3.mga8
+ Revision: 1531007
- Mageia 8 Mass Rebuild

* Sun Sep 08 2019 wally <wally> 1.4.15-2.mga8
+ Revision: 1438450
- rebuild for python3.8

* Fri Apr 26 2019 ngompa <ngompa> 1.4.15-1.mga7
+ Revision: 1395575
- Update to 1.4.15

* Tue Mar 05 2019 wally <wally> 1.4.14-2.mga7
+ Revision: 1371702
- require python3-jinja2

* Thu Feb 21 2019 ngompa <ngompa> 1.4.14-1.mga7
+ Revision: 1369206
- Update to 1.4.14

* Mon Jan 21 2019 ngompa <ngompa> 1.4.13-1.mga7
+ Revision: 1358714
- Update to 1.4.13

* Sat Jan 05 2019 wally <wally> 1.4.11-5.mga7
+ Revision: 1349836
- rebuild for python3.7

* Sun Sep 23 2018 umeabot <umeabot> 1.4.11-4.mga7
+ Revision: 1299579
- Mageia 7 Mass Rebuild

* Tue Aug 07 2018 wally <wally> 1.4.11-3.mga7
+ Revision: 1248824
- restore pycache

* Fri Jul 06 2018 daviddavid <daviddavid> 1.4.11-2.mga7
+ Revision: 1242149
- update files list (no more __pycache__ reference)

* Sat Jun 30 2018 ngompa <ngompa> 1.4.11-1.mga7
+ Revision: 1240956
- Update to 1.4.11

* Sun Apr 22 2018 wally <wally> 1.4.9-2.mga7
+ Revision: 1221096
- drop fall back to C locale patch as we have C.UTF-8 nowadays

* Mon Feb 26 2018 ngompa <ngompa> 1.4.9-1.mga7
+ Revision: 1205196
- Upgrade to 1.4.9

* Sun Dec 10 2017 ngompa <ngompa> 1.4.7-1.mga7
+ Revision: 1181906
- Upgrade to v1.4.7

* Sat Aug 05 2017 pterjan <pterjan> 1.4.2-2.mga7
+ Revision: 1135274
- Rebuild for python 3.6

* Sat Jun 10 2017 ngompa <ngompa> 1.4.2-1.mga6
+ Revision: 1107507
- Add patch to switch from C.UTF-8 to C, since C.UTF-8 is unsupported in Mageia
- Upgrade to 1.4.2

* Sun May 07 2017 ngompa <ngompa> 1.4.1-1.mga6
+ Revision: 1099460
- Update to 1.4.1

* Thu Mar 16 2017 ngompa <ngompa> 1.3.5-1.mga6
+ Revision: 1093176
- Backport patch to add %%distro_section definition to Mageia configs
- Update to v1.3.5

* Tue Feb 21 2017 ngompa <ngompa> 1.3.2-2.mga6
+ Revision: 1087211
- Add mock-mageia-configs to be installed by default with mock

* Mon Nov 21 2016 ngompa <ngompa> 1.3.2-1.mga6
+ Revision: 1068551
- Update to v1.3.2

* Tue Sep 13 2016 ngompa <ngompa> 1.2.21-1.mga6
+ Revision: 1051975
- Upgrade to 1.2.21

* Mon Sep 05 2016 ngompa <ngompa> 1.2.20-1.mga6
+ Revision: 1050062
- Update to 1.2.20

* Fri Jun 10 2016 ngompa <ngompa> 1.2.18-1.mga6
+ Revision: 1021050
- Update to 1.2.18

* Fri Jun 03 2016 ngompa <ngompa> 1.2.17-6.mga6
+ Revision: 1020194
- Actually install Mageia configs

* Fri Jun 03 2016 ngompa <ngompa> 1.2.17-5.mga6
+ Revision: 1020081
- Replace python exec with sed to read mock arch in %%post

* Wed Jun 01 2016 ngompa <ngompa> 1.2.17-4.mga6
+ Revision: 1019726
- Fix %%post again by escaping %%distro_arch macro read

* Wed Jun 01 2016 ngompa <ngompa> 1.2.17-3.mga6
+ Revision: 1019662
- Fix %%post for setting default.cfg

* Mon May 30 2016 ngompa <ngompa> 1.2.17-2.mga6
+ Revision: 1019512
- * Use distro_arch macro for setting default build target config
  * Add patches to add Mageia targets to mock

* Tue Mar 15 2016 ngompa <ngompa> 1.2.17-1.mga6
+ Revision: 990752
- Update to 1.2.17

* Fri Feb 19 2016 umeabot <umeabot> 1.2.12-2.mga6
+ Revision: 970864
- Mageia 6 Mass Rebuild

* Sat Oct 10 2015 ovitters <ovitters> 1.2.12-1.mga6
+ Revision: 888714
- update filelist
- new version 1.2.12
- update source url
- new version 1.1.24

* Wed Oct 15 2014 umeabot <umeabot> 0.9.14-8.mga5
+ Revision: 744540
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0.9.14-7.mga5
+ Revision: 682554
- Mageia 5 Mass Rebuild
+ pterjan <pterjan>
- Rebuild for new Python

* Fri Oct 18 2013 umeabot <umeabot> 0.9.14-5.mga4
+ Revision: 507963
- Mageia 4 Mass Rebuild

* Sat Jan 12 2013 umeabot <umeabot> 0.9.14-4.mga3
+ Revision: 360177
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Mon Jun 20 2011 dmorgan <dmorgan> 0.9.14-3.mga2
+ Revision: 110479
- imported package mock


* Tue Nov 02 2010 Michael Scherer <misc@mandriva.org> 0.9.14-3mdv2011.0
+ Revision: 592412
- rebuild for python 2.7

* Mon Sep 14 2009 Thierry Vignaud <tv@mandriva.org> 0.9.14-2mdv2010.0
+ Revision: 440053
- rebuild

* Wed Feb 18 2009 Jérôme Soyer <saispo@mandriva.org> 0.9.14-1mdv2009.1
+ Revision: 342373
- New upstream release

* Tue Jan 06 2009 Funda Wang <fwang@mandriva.org> 0.9.13-2mdv2009.1
+ Revision: 325765
- rebuild

* Mon Nov 10 2008 David Walluck <walluck@mandriva.org> 0.9.13-1mdv2009.1
+ Revision: 301879
- 0.9.13

* Sat Oct 18 2008 David Walluck <walluck@mandriva.org> 0.9.12-1mdv2009.1
+ Revision: 295157
- 0.9.12

* Mon Aug 18 2008 David Walluck <walluck@mandriva.org> 0.9.10-2mdv2009.0
+ Revision: 273345
- Requires: python-iniparse

* Sun Aug 17 2008 David Walluck <walluck@mandriva.org> 0.9.10-1mdv2009.0
+ Revision: 272850
- 0.9.10

* Tue Jul 29 2008 Thierry Vignaud <tv@mandriva.org> 0.9.7-3mdv2009.0
+ Revision: 252670
- rebuild

* Mon Feb 11 2008 David Walluck <walluck@mandriva.org> 0.9.7-1mdv2008.1
+ Revision: 165006
- 0.9.7

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Wed Sep 19 2007 Guillaume Rousse <guillomovitch@mandriva.org> 0.7.4-2mdv2008.0
+ Revision: 89947
- rebuild

* Sat Aug 11 2007 David Walluck <walluck@mandriva.org> 0.7.4-1mdv2008.0
+ Revision: 61853
- change selinux BuildRequires
- Import mock



* Wed Jul 18 2007 Michael Brown <mebrown@michaels-house.net> - 0.7.4-1
- return child exit status, so we properly report subcommand failures

* Fri Jul  6 2007 Michael Brown <mebrown@michaels-house.net> - 0.7.3-1
- remove redundant defaults.cfg entries.

* Wed Jun 20 2007 Michael Brown <mebrown@michaels-house.net> - 0.7.2-1
- fix exclude list
- remove legacy configs
- disable 'local' repos by default (koji-repos)

* Wed Jun 13 2007 Michael Brown <mebrown@michaels-house.net> - 0.7.1-1
- Fix problem with autocache where different users couldnt share same cache
- Fix problem creating resolv.conf in rootfs
- cleanup perms on rootfs /etc/

* Tue Jun 12 2007 Michael Brown <mebrown@michaels-house.net> - 0.7.1-1
- add EPEL 5 config files

* Mon Jun 11 2007 Clark Williams <williams@redhat.com> - 0.7-1
- fixed bind mount problems
- added code to allow multiple users to use --no-clean
- merged mock-0-6-branch to head and changed version

* Thu Jun  7 2007 Clark Williams <williams@redhat.com> - 0.6.17-1
- added F-7 config files (BZ#242276)
- modified epel configs for changed mirrorlist location (BZ#239981)
- added bind mount of /dev (BZ#236428)
- added copy of /etc/resolv.conf to chroot (BZ#237663 and BZ#238101)

* Tue May 01 2007 Clark Williams <williams@redhat.com> - 0.6.16-1
- timeout code adds new cmdline option that will kill build process after
  specified timeout. Useful for automated builds of things that may hang during
  build and you just want it to fail.

* Tue Apr 10 2007 Clark Williams <williams@redhat.com> - 0.6.15-1
- Fixed typo in FC4 -epel configs (BZ 235490)

* Sat Feb 24 2007 Clark Williams <williams@redhat.com> - 0.6.14-1
- Ville Skyttä's fix for RPM_OPT_FLAGS (BZ 226673)

* Tue Feb 20 2007 Clark Williams <williams@redhat.com> - 0.6.13-1
- Handle --no-clean option when doing yum.conf symlink (BZ 230824)

* Fri Feb 16 2007 Clark Williams <williams@redhat.com> - 0.6.12-1
- added safety symlink for yum.conf

* Wed Feb  7 2007 Clark Williams <williams@redhat.com> - 0.6.11-1
- added error() calls to print command output on failed commands

* Tue Feb  6 2007 Clark Williams <williams@redhat.com> - 0.6.11-1
- added installdeps command for long-term chroot management

* Mon Jan  8 2007 Clark Williams <williams@redhat.com> - 0.6.10-1
- Added Josh Boyer's EPEL config files

* Tue Nov 21 2006 Clark Williams <williams@redhat.com> - 0.6.9-1
- applied Eric Work's patch to fix defaults vs. command line option problem
  (BZ 215168)
- use /etc/mock/defaults.cfg if --configdir specified and no defaults found
  in the specified configdir
  (BZ 209407)
- applied Jesse Keatings patch for arch specifi config files
  (BZ 213516)

* Mon Oct 30 2006 Clark Williams <williams@redhat.com> - 0.6.8-1
- respun tarballs without buildsys rpms

* Mon Oct 30 2006 Clark Williams <williams@redhat.com> - 0.6.7-1
- updated for FC6 release

* Sat Oct 21 2006 Clark Williams <williams@redhat.com> - 0.6.6-1
- bumped version to 0.6.6 (fixed tarball problem)

* Mon Sep 11 2006 Clark Williams <williams@redhat.com> - 0.6.5-1
- changed version number for patch from Karanbir Singh
  (rpm workaround on CentOS 4.4)

* Tue Aug 29 2006 Clark Williams <williams@redhat.com> - 0.6.3-1
- changed version number to indicate fix for bz 204051

* Tue Aug 29 2006 Clark Williams <williams@redhat.com> - 0.6.2-2
- bumped revision for bz 204051

* Wed Aug 23 2006 Clark Williams <williams@redhat.com> - 0.6.2-1
- Updated README
- Fixed link problem in etc/Makefile
- Bumped version number

* Wed Aug 16 2006 Clark Williams <williams@redhat.com>
- Added buildsys-build specfile to docs
- Added disttag
- Bumped release number

* Wed Jun  7 2006 Seth Vidal <skvidal at linux.duke.edu>
- version update

* Tue Apr 11 2006 Seth Vidal <skvidal at linux.duke.edu>
- specfile version iterate

* Tue Dec 27 2005 Seth Vidal <skvidal@phy.duke.edu>
- add patch from Andreas Thienemann - adds man page

* Sat Jun 11 2005 Seth Vidal <skvidal@phy.duke.edu>
- security fix in mock-helper

* Sun Jun  5 2005 Seth Vidal <skvidal@phy.duke.edu>
- clean up packaging for fedora extras

* Thu May 19 2005 Seth Vidal <skvidal@phy.duke.edu>
- second packaging and backing down the yum ver req

* Sun May 15 2005 Seth Vidal <skvidal@phy.duke.edu>
- first version/packaging
